/// <reference types="node" />
import { BigNumber } from 'ethers';
import { AptosClient, CoinClient, Types } from 'aptos';
import { TokenId, ParsedRelayerMessage, ChainName, ChainId, NATIVE, ParsedMessage, Context, ParsedRelayerPayload, Wormhole, TokenBridgeAbstract } from '@wormhole-foundation/connect-sdk';
import { AptosContracts } from './contracts';
export declare const APTOS_COIN = "0x1::aptos_coin::AptosCoin";
/**
 * @category Aptos
 */
export declare class AptosContext extends TokenBridgeAbstract<Types.EntryFunctionPayload> {
    readonly type = Context.APTOS;
    readonly contracts: AptosContracts;
    protected wormhole: Wormhole;
    readonly aptosClient: AptosClient;
    readonly coinClient: CoinClient;
    constructor(wormholeInstance: Wormhole);
    startTransfer(token: TokenId | typeof NATIVE, amount: bigint, sendingChain: ChainName | ChainId, senderAddress: string, recipientChain: ChainName | ChainId, recipientAddress: string, relayerFee?: string): Promise<Types.EntryFunctionPayload>;
    startTransferWithPayload(token: TokenId | typeof NATIVE, amount: bigint, sendingChain: ChainName | ChainId, senderAddress: string, recipientChain: ChainName | ChainId, recipientAddress: string, payload: any): Promise<Types.EntryFunctionPayload>;
    formatAddress(address: string): Uint8Array;
    parseAddress(address: string): string;
    formatAssetAddress(address: string): Promise<Uint8Array>;
    parseAssetAddress(address: string): Promise<string>;
    getForeignAsset(tokenId: TokenId, chain: ChainName | ChainId): Promise<string | null>;
    mustGetForeignAsset(tokenId: TokenId, chain: ChainName | ChainId): Promise<string>;
    fetchTokenDecimals(tokenAddr: string, chain: ChainName | ChainId): Promise<number>;
    parseMessageFromTx(tx: string, chain: ChainName | ChainId): Promise<ParsedMessage[] | ParsedRelayerMessage[]>;
    getNativeBalance(walletAddress: string, chain: ChainName | ChainId): Promise<BigNumber>;
    getTokenBalance(walletAddress: string, tokenId: TokenId, chain: ChainName | ChainId): Promise<BigNumber | null>;
    checkBalance(walletAddress: string, coinType: string): Promise<BigNumber>;
    completeTransfer(destChain: ChainName | ChainId, signedVAA: Uint8Array, overrides: any, payerAddr?: any): Promise<Types.EntryFunctionPayload>;
    isTransferCompleted(destChain: ChainName | ChainId, signedVaa: string): Promise<boolean>;
    getTxIdFromReceipt(hash: Types.HexEncodedBytes): string;
    parseRelayerPayload(payload: Buffer): ParsedRelayerPayload;
    getCurrentBlock(): Promise<number>;
}
