"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getForeignAssetAptos = void 0;
const utils_1 = require("./utils");
/**
 * Get qualified type of asset on Aptos given its origin info.
 * @param client Client used to transfer data to/from Aptos node
 * @param tokenBridgeAddress Address of token bridge
 * @param originChainId Chain ID of chain asset is originally from
 * @param originAddress Asset address on origin chain
 * @returns Fully qualified type of asset on Aptos
 */
async function getForeignAssetAptos(client, tokenBridgeAddress, originChainId, originAddress) {
    const assetFullyQualifiedType = (0, utils_1.getAssetFullyQualifiedType)(tokenBridgeAddress, originChainId, originAddress);
    if (!assetFullyQualifiedType) {
        return null;
    }
    try {
        // check if asset exists and throw if it doesn't
        await client.getAccountResource((0, utils_1.coalesceModuleAddress)(assetFullyQualifiedType), `0x1::coin::CoinInfo<${assetFullyQualifiedType}>`);
        return assetFullyQualifiedType;
    }
    catch (e) {
        return null;
    }
}
exports.getForeignAssetAptos = getForeignAssetAptos;
//# sourceMappingURL=getForeignAsset.js.map