"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.redeemOnAptos = exports.completeTransferAndRegister = void 0;
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
const utils_1 = require("./utils");
const vaa_1 = require("./vaa");
const completeTransferAndRegister = async (client, tokenBridgeAddress, transferVAA) => {
    if (!tokenBridgeAddress)
        throw new Error('Need token bridge address.');
    const parsedVAA = (0, vaa_1._parseVAAAlgorand)(transferVAA);
    if (!parsedVAA.FromChain || !parsedVAA.Contract || !parsedVAA.ToChain) {
        throw new Error('VAA does not contain required information');
    }
    if (parsedVAA.ToChain !== connect_sdk_1.MAINNET_CHAINS.aptos) {
        throw new Error('Transfer is not destined for Aptos');
    }
    // assertChain(parsedVAA.FromChain);
    const assetType = parsedVAA.FromChain === connect_sdk_1.MAINNET_CHAINS.aptos
        ? await (0, utils_1.getTypeFromExternalAddress)(client, tokenBridgeAddress, parsedVAA.Contract)
        : (0, utils_1.getAssetFullyQualifiedType)(tokenBridgeAddress, parsedVAA.FromChain, parsedVAA.Contract);
    if (!assetType)
        throw new Error('Invalid asset address.');
    return {
        function: `${tokenBridgeAddress}::complete_transfer::submit_vaa_and_register_entry`,
        type_arguments: [assetType],
        arguments: [transferVAA],
    };
};
exports.completeTransferAndRegister = completeTransferAndRegister;
/**
 * Register the token specified in the given VAA in the transfer recipient's account if necessary
 * and complete the transfer.
 * @param client Client used to transfer data to/from Aptos node
 * @param tokenBridgeAddress Address of token bridge
 * @param transferVAA Bytes of transfer VAA
 * @returns Transaction payload
 */
function redeemOnAptos(client, tokenBridgeAddress, transferVAA) {
    return (0, exports.completeTransferAndRegister)(client, tokenBridgeAddress, transferVAA);
}
exports.redeemOnAptos = redeemOnAptos;
//# sourceMappingURL=redeem.js.map