"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transferFromAptos = exports.transferTokensWithPayload = exports.transferTokens = void 0;
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
const utils_1 = require("./utils");
const transferTokens = (tokenBridgeAddress, fullyQualifiedType, amount, recipientChainId, recipient, relayerFee, nonce) => {
    if (!tokenBridgeAddress)
        throw new Error('Need token bridge address.');
    if (!(0, utils_1.isValidAptosType)(fullyQualifiedType)) {
        throw new Error('Invalid qualified type');
    }
    return {
        function: `${tokenBridgeAddress}::transfer_tokens::transfer_tokens_entry`,
        type_arguments: [fullyQualifiedType],
        arguments: [amount, recipientChainId, recipient, relayerFee, nonce],
    };
};
exports.transferTokens = transferTokens;
const transferTokensWithPayload = (tokenBridgeAddress, fullyQualifiedType, amount, recipientChain, recipient, relayerFee, nonce, payload) => {
    throw new Error('Transfer with payload are not yet supported in the sdk');
};
exports.transferTokensWithPayload = transferTokensWithPayload;
/**
 * Transfer an asset on Aptos to another chain.
 * @param tokenBridgeAddress Address of token bridge
 * @param fullyQualifiedType Full qualified type of asset to transfer
 * @param amount Amount to send to recipient
 * @param recipientChain Target chain
 * @param recipient Recipient's address on target chain
 * @param relayerFee Fee to pay relayer
 * @param payload Payload3 data, leave undefined for basic token transfers
 * @returns Transaction payload
 */
function transferFromAptos(tokenBridgeAddress, fullyQualifiedType, amount, recipientChain, recipient, relayerFee = '0', payload = '') {
    if (payload) {
        // Currently unsupported
        return (0, exports.transferTokensWithPayload)(tokenBridgeAddress, fullyQualifiedType, amount, recipientChain, recipient, relayerFee, (0, connect_sdk_1.createNonce)().readUInt32LE(0), payload);
    }
    return (0, exports.transferTokens)(tokenBridgeAddress, fullyQualifiedType, amount, recipientChain, recipient, relayerFee, (0, connect_sdk_1.createNonce)().readUInt32LE(0));
}
exports.transferFromAptos = transferFromAptos;
//# sourceMappingURL=transfer.js.map